@@ -69,7 +69,6 @@ EXCLUDE = (
   "cmd/smyrna/gui/topviewsettings.c",
   "cmd/smyrna/gui/topviewsettings.h",
   "cmd/smyrna/gvprpipe.c",
-  "cmd/smyrna/gvprpipe.h",
   "cmd/smyrna/hier.c",
   "cmd/smyrna/hier.h",
   "cmd/smyrna/hotkeymap.c",
@@ -179,7 +178,6 @@ EXCLUDE = (
   "lib/cgraph/node.c",
   "lib/cgraph/obj.c",
   "lib/cgraph/pend.c",
-  "lib/cgraph/prisize_t.h",
   "lib/cgraph/rec.c",
   "lib/cgraph/refstr.c",
   "lib/cgraph/subg.c",
