@@ -8,6 +8,7 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include <stdbool.h>
 #include <stdio.h>
 
 #include <stdlib.h>
@@ -16,20 +17,21 @@
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdk.h>
 #include "viewport.h"
-#include <common/memory.h>
 #include "frmobjectui.h"
 #include <assert.h>
 #include <ast/sfstr.h>
 #include "gvprpipe.h"
 #include <cgraph/agxbuf.h>
+#include <cgraph/alloc.h>
 #include <cgraph/strcasecmp.h>
+#include <cgraph/strview.h>
+#include <string.h>
 
 static int sel_node;
 static int sel_edge;
 static int sel_graph;
 
-static char *safestrdup(char *src)
-{
+static char *safestrdup(const char *src) {
     if (!src)
 	return NULL;
     else
@@ -59,7 +61,7 @@ static void free_attr(attr_t *at) {
 }
 
 static attr_t *new_attr(void) {
-    attr_t *attr = malloc(sizeof(attr_t));
+    attr_t *attr = gv_alloc(sizeof(attr_t));
     attr->defValG = NULL;
     attr->defValN = NULL;
     attr->defValE = NULL;
@@ -98,7 +100,7 @@ static attr_t *new_attr_with_ref(Agsym_t * sym)
 
 static attr_t *new_attr_ref(attr_t * refAttr)
 {
-    attr_t *attr = malloc(sizeof(attr_t));
+    attr_t *attr = gv_alloc(sizeof(attr_t));
     *attr = *refAttr;
     attr->defValG = safestrdup(refAttr->defValG);
     attr->defValN = safestrdup(refAttr->defValN);
@@ -141,10 +143,10 @@ static void free_attr_list(attr_list *l) {
 // that uses quicksort
 static attr_list *attr_list_new(Agraph_t *g, int with_widgets) {
     int id;
-    attr_list *l = malloc(sizeof(attr_list));
+    attr_list *l = gv_alloc(sizeof(attr_list));
     l->attr_count = 0;
     l->capacity = DEFAULT_ATTR_LIST_CAPACITY;
-    l->attributes = malloc(DEFAULT_ATTR_LIST_CAPACITY * sizeof(attr_t *));
+    l->attributes = gv_calloc(DEFAULT_ATTR_LIST_CAPACITY, sizeof(attr_t*));
     l->with_widgets = with_widgets;
     /*create filter widgets */
 
@@ -186,9 +188,10 @@ static void attr_list_add(attr_list *l, attr_t *a) {
 	return;
     l->attr_count++;
     if (l->attr_count == l->capacity) {
+	l->attributes = gv_recalloc(l->attributes, l->capacity,
+	                            l->capacity + EXPAND_CAPACITY_VALUE,
+	                            sizeof(attr_t *));
 	l->capacity = l->capacity + EXPAND_CAPACITY_VALUE;
-	l->attributes =
-	    realloc(l->attributes, l->capacity * sizeof(attr_t *));
     }
     l->attributes[l->attr_count - 1] = a;
     if (l->attr_count > 1)
@@ -217,30 +220,39 @@ static attr_data_type get_attr_data_type(char c)
     return attr_alpha;
 }
 
-static void object_type_helper(char *a, int *t)
-{
-    if (strcmp(a, "GRAPH") == 0)
+static void object_type_helper(strview_t a, int *t) {
+    if (strview_str_eq(a, "GRAPH"))
 	t[0] = 1;
-    if (strcmp(a, "CLUSTER") == 0)
+    if (strview_str_eq(a, "CLUSTER"))
 	t[0] = 1;
-    if (strcmp(a, "NODE") == 0)
+    if (strview_str_eq(a, "NODE"))
 	t[1] = 1;
-    if (strcmp(a, "EDGE") == 0)
+    if (strview_str_eq(a, "EDGE"))
 	t[2] = 1;
-    if (strcmp(a, "ANY_ELEMENT") == 0) {
+    if (strview_str_eq(a, "ANY_ELEMENT")) {
 	t[0] = 1;
 	t[1] = 1;
 	t[2] = 1;
     }
 }
 
-static void set_attr_object_type(char *str, int *t)
-{
-    char *a;
-    a = strtok(str, " ");
+static void set_attr_object_type(const char *str, int *t) {
+  strview_t a = strview(str, ' ');
+  object_type_helper(a, t);
+  while (true) {
+    const char *start = a.data + a.size;
+    if (strncmp(start, " or ", strlen(" or ")) != 0) {
+      break;
+    }
+    start += strlen(" or ");
+    const char *end = strstr(start, " or ");
+    if (end == NULL) {
+      a = strview(start, '\0');
+    } else {
+      a = (strview_t){.data = start, .size = (size_t)(end - start)};
+    }
     object_type_helper(a, t);
-    while ((a = strtok(NULL, " or ")))
-	object_type_helper(a, t);
+  }
 }
 
 static attr_t *binarySearch(attr_list * l, char *searchKey)
@@ -422,11 +434,9 @@ static void set_refresh_filters(ViewInfo * v, int type, char *name)
 	v->refresh.selection = 1;
 }
 
-static void doApply (GtkWidget * widget, int doAll)
+static void doApply(void)
 {
     char *attr_name;
-    char *value;
-    char *def_val;
     int prog;
     Agnode_t *v;
     Agedge_t *e;
@@ -439,12 +449,10 @@ static void doApply (GtkWidget * widget, int doAll)
     attr_name =
 	(char *) gtk_entry_get_text((GtkEntry *)
 				    glade_xml_get_widget(xml, "txtAttr"));
-    def_val =
-	(char *) gtk_entry_get_text((GtkEntry *)
+    const char *def_val = gtk_entry_get_text((GtkEntry *)
 				    glade_xml_get_widget(xml,
 							 "txtDefValue"));
-    value =
-	(char *) gtk_entry_get_text((GtkEntry *)
+    const char *value = gtk_entry_get_text((GtkEntry *)
 				    glade_xml_get_widget(xml, "txtValue"));
     prog =
 	gtk_toggle_button_get_active((GtkToggleButton *)
@@ -464,7 +472,7 @@ static void doApply (GtkWidget * widget, int doAll)
     /*nodes */
     else if (objKind == AGNODE) {
 	for (v = agfstnode(g); v; v = agnxtnode(g, v)) {
-	    if (doAll || ND_selected(v))
+	    if (ND_selected(v))
 		agxset(v, sym, value);
 	}
     }
@@ -472,7 +480,7 @@ static void doApply (GtkWidget * widget, int doAll)
     else if (objKind == AGEDGE) {
 	for (v = agfstnode(g); v; v = agnxtnode(g, v)) {
 	    for (e = agfstout(g, v); e; e = agnxtout(g, e)) {
-		if (doAll || ED_selected(e))
+		if (ED_selected(e))
 		    agxset(e, sym, value);
 	    }
 	}
@@ -485,8 +493,10 @@ static void doApply (GtkWidget * widget, int doAll)
 
 _BB void on_attrApplyBtn_clicked(GtkWidget * widget, gpointer user_data)
 {
+    (void)widget;
     (void)user_data;
-    doApply (widget, 0);
+
+    doApply();
 }
 
 /* This is the action attached to the publish button on the attributes
@@ -501,8 +511,10 @@ _BB void on_attrProg_toggled(GtkWidget * widget, gpointer user_data)
 
 _BB void on_attrAddBtn_clicked(GtkWidget * widget, gpointer user_data)
 {
+    (void)widget;
+    (void)user_data;
+
     char *attr_name;
-    char *defValue;
     int objKind;
     topview *t;
     Agraph_t *g;
@@ -513,8 +525,7 @@ _BB void on_attrAddBtn_clicked(GtkWidget * widget, gpointer user_data)
     attr_name =
 	(char *) gtk_entry_get_text((GtkEntry *)
 				    glade_xml_get_widget(xml, "txtAttr"));
-    defValue =
-	(char *) gtk_entry_get_text((GtkEntry *)
+    const char *defValue = gtk_entry_get_text((GtkEntry *)
 				    glade_xml_get_widget(xml,
 							 "txtDefValue"));
     g = view->g[view->activeGraph];
