@@ -8,12 +8,14 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-
+#include <cgraph/agxbuf.h>
+#include <cgraph/unreachable.h>
 #include <common/render.h>
 #include <label/xlabels.h>
+#include <stdbool.h>
 
 static int Rankdir;
-static boolean Flip;
+static bool Flip;
 static pointf Offset;
 
 static void place_flip_graph_label(graph_t * g);
@@ -90,7 +92,7 @@ static void map_edge(edge_t * e)
     bezier bz;
 
     if (ED_spl(e) == NULL) {
-	if ((Concentrate == FALSE) && (ED_edge_type(e) != IGNORED))
+	if (!Concentrate && ED_edge_type(e) != IGNORED)
 	    agerr(AGERR, "lost %s %s edge\n", agnameof(agtail(e)),
 		  agnameof(aghead(e)));
 	return;
@@ -145,13 +147,13 @@ static void translate_drawing(graph_t * g)
 {
     node_t *v;
     edge_t *e;
-    int shift = (Offset.x || Offset.y);
+    bool shift = Offset.x || Offset.y;
 
     if (!shift && !Rankdir)
 	return;
     for (v = agfstnode(g); v; v = agnxtnode(g, v)) {
 	if (Rankdir)
-	    gv_nodesize(v, FALSE);
+	    gv_nodesize(v, false);
 	ND_coord(v) = map_point(ND_coord(v));
 	if (ND_xlabel(v))
 	    ND_xlabel(v)->pos = map_point(ND_xlabel(v)->pos);
@@ -199,8 +201,8 @@ centerPt (xlabel_t* xlp) {
   pointf p;
 
   p = xlp->pos;
-  p.x += (xlp->sz.x)/2.0;
-  p.y += (xlp->sz.y)/2.0;
+  p.x += xlp->sz.x / 2.0;
+  p.y += xlp->sz.y / 2.0;
 
   return p;
 }
@@ -217,15 +219,16 @@ printData (object_t* objs, int n_objs, xlabel_t* lbls, int n_lbls,
   fprintf(stderr, "objects\n");
   for (i = 0; i < n_objs; i++) {
     xp = objs->lbl;
-    fprintf (stderr, " [%d] (%.02f,%.02f) (%.02f,%.02f) %p \"%s\"\n",
-	    i, objs->pos.x,objs->pos.y,objs->sz.x,objs->sz.y, objs->lbl, 
-	    (xp?((textlabel_t*)(xp->lbl))->text:""));
+    fprintf(stderr, " [%d] (%.02f,%.02f) (%.02f,%.02f) %p \"%s\"\n",
+            i, objs->pos.x, objs->pos.y, objs->sz.x, objs->sz.y, objs->lbl,
+            xp ? ((textlabel_t*)xp->lbl)->text : "");
     objs++;
   }
   fprintf(stderr, "xlabels\n");
   for (i = 0; i < n_lbls; i++) {
-    fprintf (stderr, " [%d] %p set %d (%.02f,%.02f) (%.02f,%.02f) %s\n",
-	     i, lbls,  lbls->set, lbls->pos.x,lbls->pos.y, lbls->sz.x,lbls->sz.y, ((textlabel_t*)lbls->lbl)->text);  
+    fprintf(stderr, " [%d] %p set %d (%.02f,%.02f) (%.02f,%.02f) %s\n",
+            i, lbls, lbls->set, lbls->pos.x, lbls->pos.y, lbls->sz.x,
+            lbls->sz.y, ((textlabel_t*)lbls->lbl)->text);
     lbls++;
   }
   return 0;
@@ -330,8 +333,8 @@ addLabelObj (textlabel_t* lp, object_t* objp, boxf bb)
 	objp->sz.y = lp->dimen.y;
     }
     objp->pos = lp->pos;
-    objp->pos.x -= (objp->sz.x) / 2.0;
-    objp->pos.y -= (objp->sz.y) / 2.0;
+    objp->pos.x -= objp->sz.x / 2.0;
+    objp->pos.y -= objp->sz.y / 2.0;
 
     return adjustBB(objp, bb);
 }
@@ -353,8 +356,8 @@ addNodeObj (node_t* np, object_t* objp, boxf bb)
 	objp->sz.y = INCH2PS(ND_height(np));
     }
     objp->pos = ND_coord(np);
-    objp->pos.x -= (objp->sz.x) / 2.0;
-    objp->pos.y -= (objp->sz.y) / 2.0;
+    objp->pos.x -= objp->sz.x / 2.0;
+    objp->pos.y -= objp->sz.y / 2.0;
 
     return adjustBB(objp, bb);
 }
@@ -371,7 +374,7 @@ addClusterObj (Agraph_t* g, cinfo_t info)
 
     for (c = 1; c <= GD_n_cluster(g); c++)
 	info = addClusterObj (GD_clust(g)[c], info);
-    if ((g != agroot(g)) && (GD_label(g)) && GD_label(g)->set) {
+    if (g != agroot(g) && GD_label(g) && GD_label(g)->set) {
 	object_t* objp = info.objp;
 	info.bb = addLabelObj (GD_label(g), objp, info.bb);
 	info.objp++;
@@ -384,7 +387,7 @@ static int
 countClusterLabels (Agraph_t* g)
 {
     int c, i = 0;
-    if ((g != agroot(g)) && (GD_label(g)) && GD_label(g)->set)
+    if (g != agroot(g) && GD_label(g) && GD_label(g)->set)
 	i++;
     for (c = 1; c <= GD_n_cluster(g); c++)
 	i += countClusterLabels (GD_clust(g)[c]);
@@ -398,7 +401,7 @@ countClusterLabels (Agraph_t* g)
  * TODO: interaction with spline=ortho
  */
   /* True if edges geometries were computed and this edge has a geometry */
-#define HAVE_EDGE(ep) ((et != ET_NONE) && (ED_spl(ep) != NULL))
+#define HAVE_EDGE(ep) ((et != EDGETYPE_NONE) && (ED_spl(ep) != NULL))
 
 static void addXLabels(Agraph_t * gp)
 {
@@ -564,7 +567,7 @@ static void addXLabels(Agraph_t * gp)
 
     force = agfindgraphattr(gp, "forcelabels");
 
-    params.force = late_bool(gp, force, TRUE);
+    params.force = late_bool(gp, force, true);
     params.bb = bb;
     placeLabels(objs, n_objs, lbls, n_lbls, &params);
     if (Verbose)
@@ -575,7 +578,7 @@ static void addXLabels(Agraph_t * gp)
     for (i = 0; i < n_lbls; i++) {
 	if (xlp->set) {
 	    cnt++;
-	    lp = (textlabel_t *) (xlp->lbl);
+	    lp = (textlabel_t *)xlp->lbl;
 	    lp->set = 1;
 	    lp->pos = centerPt(xlp);
 	    updateBB (gp, lp);
@@ -627,7 +630,7 @@ void gv_postprocess(Agraph_t * g, int allowTranslation)
 		GD_bb(g).LL.x -= dimen.y;
 	    }
 
-	    if (dimen.x > (GD_bb(g).UR.y - GD_bb(g).LL.y)) {
+	    if (dimen.x > GD_bb(g).UR.y - GD_bb(g).LL.y) {
 		diff = dimen.x - (GD_bb(g).UR.y - GD_bb(g).LL.y);
 		diff = diff / 2.;
 		GD_bb(g).LL.y -= diff;
@@ -646,7 +649,7 @@ void gv_postprocess(Agraph_t * g, int allowTranslation)
 		    GD_bb(g).UR.y += dimen.y;
 	    }
 
-	    if (dimen.x > (GD_bb(g).UR.x - GD_bb(g).LL.x)) {
+	    if (dimen.x > GD_bb(g).UR.x - GD_bb(g).LL.x) {
 		diff = dimen.x - (GD_bb(g).UR.x - GD_bb(g).LL.x);
 		diff = diff / 2.;
 		GD_bb(g).LL.x -= diff;
@@ -668,6 +671,8 @@ void gv_postprocess(Agraph_t * g, int allowTranslation)
 	case RANKDIR_RL:
 	    Offset = pointfof(GD_bb(g).LL.y, GD_bb(g).LL.x);
 	    break;
+	default:
+	    UNREACHABLE();
 	}
 	translate_drawing(g);
     }
@@ -675,13 +680,13 @@ void gv_postprocess(Agraph_t * g, int allowTranslation)
 	place_root_label(g, dimen);
 
     if (Show_boxes) {
-	char buf[BUFSIZ];
+	agxbuf buf = {0};
 	if (Flip)
-	    snprintf(buf, sizeof(buf), M2, Offset.x, Offset.y, Offset.x, Offset.y);
+	    agxbprint(&buf, M2, Offset.x, Offset.y, Offset.x, Offset.y);
 	else
-	    snprintf(buf, sizeof(buf), M1, Offset.y, Offset.x, Offset.y, Offset.x,
+	    agxbprint(&buf, M1, Offset.y, Offset.x, Offset.y, Offset.x,
 		    -Offset.x, -Offset.y);
-	Show_boxes[0] = strdup(buf);
+	Show_boxes[0] = agxbdisown(&buf);
     }
 }
 
@@ -700,7 +705,7 @@ static void place_flip_graph_label(graph_t * g)
     int c;
     pointf p, d;
 
-    if ((g != agroot(g)) && (GD_label(g)) && !GD_label(g)->set) {
+    if (g != agroot(g) && GD_label(g) && !GD_label(g)->set) {
 	if (GD_label_pos(g) & LABEL_AT_TOP) {
 	    d = GD_border(g)[RIGHT_IX];
 	    p.x = GD_bb(g).UR.x - d.x / 2;
@@ -735,7 +740,7 @@ void place_graph_label(graph_t * g)
     int c;
     pointf p, d;
 
-    if ((g != agroot(g)) && (GD_label(g)) && !GD_label(g)->set) {
+    if (g != agroot(g) && GD_label(g) && !GD_label(g)->set) {
 	if (GD_label_pos(g) & LABEL_AT_TOP) {
 	    d = GD_border(g)[TOP_IX];
 	    p.y = GD_bb(g).UR.y - d.y / 2;
@@ -752,7 +757,7 @@ void place_graph_label(graph_t * g)
 	    p.x = (GD_bb(g).LL.x + GD_bb(g).UR.x) / 2;
 	}
 	GD_label(g)->pos = p;
-	GD_label(g)->set = TRUE;
+	GD_label(g)->set = true;
     }
 
     for (c = 1; c <= GD_n_cluster(g); c++)
