@@ -9,10 +9,12 @@
  *************************************************************************/
 
 #include <common/render.h>
+#include <cgraph/alloc.h>
 #include <cgraph/agxbuf.h>
+#include <cgraph/strview.h>
+#include <cgraph/tokenize.h>
 #include <common/htmltable.h>
 #include <common/entities.h>
-#include <common/logic.h>
 #include <math.h>
 #include <gvc/gvc.h>
 #include <cgraph/strcasecmp.h>
@@ -293,17 +295,7 @@ char *Fgets(FILE * fp)
  * It returns NULL if the filename is trivial.
  *
  * If the application has set the SERVER_NAME environment variable,
- * this indicates it is web-active. In this case, it requires that the GV_FILE_PATH
- * environment variable be set. This gives the legal directories
- * from which files may be read. safefile then derives the rightmost component
- * of filename, where components are separated by a slash, backslash or colon,
- * It then checks for the existence of a file consisting of a directory from
- * GV_FILE_PATH followed by the rightmost component of filename. It returns the
- * first such found, or NULL otherwise.
- * The filename returned is thus
- * Gvfilepath concatenated with the last component of filename,
- * where a component is determined by a slash, backslash or colon
- * character.
+ * this indicates it is web-active.
  *
  * If filename contains multiple components, the user is
  * warned, once, that everything to the left is ignored.
@@ -320,28 +312,23 @@ char *Fgets(FILE * fp)
 #define PATHSEP ":"
 #endif
 
-static char** mkDirlist (const char* list, size_t* maxdirlen)
-{
-    int cnt = 0;
-    char* s = strdup (list);
-    char* dir;
-    char** dirs = NULL;
+static strview_t *mkDirlist(const char *list, size_t *maxdirlen) {
+    size_t cnt = 0;
+    strview_t *dirs = gv_calloc(1, sizeof(strview_t));
     size_t maxlen = 0;
 
-    for (dir = strtok (s, PATHSEP); dir; dir = strtok (NULL, PATHSEP)) {
-	dirs = ALLOC (cnt+2,dirs,char*);
-	dirs[cnt++] = dir;
-	maxlen = MAX(maxlen, strlen (dir));
+    for (tok_t t = tok(list, PATHSEP); !tok_end(&t); tok_next(&t)) {
+        strview_t dir = tok_get(&t);
+        dirs = gv_recalloc(dirs, cnt + 1, cnt + 2, sizeof(strview_t));
+        dirs[cnt++] = dir;
+        maxlen = MAX(maxlen, dir.size);
     }
-    dirs[cnt] = NULL;
     *maxdirlen = maxlen;
     return dirs;
 }
 
-static char* findPath (char** dirs, size_t maxdirlen, const char* str)
-{
+static char *findPath(const strview_t *dirs, size_t maxdirlen, const char *str) {
     static char *safefilename = NULL;
-    char** dp;
 
 	/* allocate a buffer that we are sure is big enough
          * +1 for null character.
@@ -349,8 +336,8 @@ static char* findPath (char** dirs, size_t maxdirlen, const char* str)
          */
     safefilename = realloc(safefilename, maxdirlen + strlen(str) + 2);
 
-    for (dp = dirs; *dp; dp++) {
-	sprintf (safefilename, "%s%s%s", *dp, DIRSEP, str);
+    for (const strview_t *dp = dirs; dp != NULL && dp->data != NULL; dp++) {
+	sprintf(safefilename, "%.*s%s%s", (int)dp->size, dp->data, DIRSEP, str);
 	if (access (safefilename, R_OK) == 0)
 	    return safefilename;
     }
@@ -362,57 +349,24 @@ const char *safefile(const char *filename)
     static bool onetime = true;
     static char *pathlist = NULL;
     static size_t maxdirlen;
-    static char** dirs;
-    const char *str, *p;
+    static strview_t *dirs;
 
     if (!filename || !filename[0])
 	return NULL;
 
     if (HTTPServerEnVar) {   /* If used as a server */
-	/*
-	 * If we are running in an http server we allow
-	 * files only from the directory specified in
-	 * the GV_FILE_PATH environment variable.
-	 */
-	if (!Gvfilepath || (*Gvfilepath == '\0')) {
-	    if (onetime) {
-		agerr(AGWARN,
-		      "file loading is disabled because the environment contains SERVER_NAME=\"%s\"\n"
-		      "and the GV_FILE_PATH variable is unset or empty.\n",
+	if (onetime) {
+	    agerr(AGWARN,
+		      "file loading is disabled because the environment contains SERVER_NAME=\"%s\"\n",
 		      HTTPServerEnVar);
-		onetime = false;
-	    }
-	    return NULL;
-	}
-	if (!pathlist) {
-	    dirs = mkDirlist (Gvfilepath, &maxdirlen);
-	    pathlist = Gvfilepath;
-	}
-
-	str = filename;
-	if ((p = strrchr(str, '/')))
-	    str = ++p;
-	if ((p = strrchr(str, '\\')))
-	    str = ++p;
-	if ((p = strrchr(str, ':')))
-	    str = ++p;
-
-	if (onetime && str != filename) {
-	    agerr(AGWARN, "Path provided to file: \"%s\" has been ignored"
-		  " because files are only permitted to be loaded from the directories in \"%s\""
-		  " when running in an http server.\n", filename, Gvfilepath);
 	    onetime = false;
 	}
-
-	return findPath (dirs, maxdirlen, str);
+	return NULL;
     }
 
     if (pathlist != Gvimagepath) {
-	if (dirs) {
-	    free (dirs[0]);
-	    free (dirs);
-	    dirs = NULL;
-	}
+	free (dirs);
+	dirs = NULL;
 	pathlist = Gvimagepath;
 	if (pathlist && *pathlist)
 	    dirs = mkDirlist (pathlist, &maxdirlen);
@@ -1432,8 +1386,6 @@ char* htmlEntityUTF8 (char* s, graph_t* g)
 {
     static graph_t* lastg;
     static bool warned;
-    char*  ns;
-    agxbuf xb;
     unsigned char c;
     unsigned int v;
 
@@ -1445,7 +1397,7 @@ char* htmlEntityUTF8 (char* s, graph_t* g)
 	warned = false;
     }
 
-    agxbinit(&xb, 0, NULL);
+    agxbuf xb = {0};
 
     while ((c = *(unsigned char*)s++)) {
         if (c < 0xC0)
@@ -1505,9 +1457,7 @@ char* htmlEntityUTF8 (char* s, graph_t* g)
 	            }
         agxbputc(&xb, (char)c);
     }
-    ns = agxbdisown(&xb);
-    agxbfree(&xb);
-    return ns;
+    return agxbdisown(&xb);
 }
 
 /* latin1ToUTF8:
@@ -1517,12 +1467,9 @@ char* htmlEntityUTF8 (char* s, graph_t* g)
  */
 char* latin1ToUTF8 (char* s)
 {
-    char*  ns;
-    agxbuf xb;
+    agxbuf xb = {0};
     unsigned int  v;
 
-    agxbinit(&xb, 0, NULL);
-
     /* Values are either a byte (<= 256) or come from htmlEntity, whose
      * values are all less than 0x07FF, so we need at most 3 bytes.
      */
@@ -1543,9 +1490,7 @@ char* latin1ToUTF8 (char* s)
 	    agxbputc(&xb, (char)((v & 0x3F) | 0x80));
 	}
     }
-    ns = agxbdisown(&xb);
-    agxbfree(&xb);
-    return ns;
+    return agxbdisown(&xb);
 }
 
 /* utf8ToLatin1:
@@ -1556,13 +1501,10 @@ char* latin1ToUTF8 (char* s)
 char*
 utf8ToLatin1 (char* s)
 {
-    char*  ns;
-    agxbuf xb;
+    agxbuf xb = {0};
     unsigned char c;
     unsigned char outc;
 
-    agxbinit(&xb, 0, NULL);
-
     while ((c = *(unsigned char*)s++)) {
 	if (c < 0x7F)
 	    agxbputc(&xb, (char)c);
@@ -1573,9 +1515,7 @@ utf8ToLatin1 (char* s)
 	    agxbputc(&xb, (char)outc);
 	}
     }
-    ns = agxbdisown(&xb);
-    agxbfree(&xb);
-    return ns;
+    return agxbdisown(&xb);
 }
 
 bool overlap_node(node_t *n, boxf b)
