@@ -20,7 +20,7 @@ glCompPanel *glCompPanelNew(glCompObj * parentObj, GLfloat x, GLfloat y,
 {
     glCompPanel *p;
     p = NEW(glCompPanel);
-    glCompInitCommon((glCompObj *) p, parentObj, (GLfloat) x, (GLfloat) y);
+    glCompInitCommon((glCompObj *) p, parentObj, x, y);
 
     p->shadowcolor.R = GLCOMPSET_PANEL_SHADOW_COLOR_R;
     p->shadowcolor.G = GLCOMPSET_PANEL_SHADOW_COLOR_G;
@@ -34,9 +34,9 @@ glCompPanel *glCompPanelNew(glCompObj * parentObj, GLfloat x, GLfloat y,
     p->common.height = h;
 
     p->common.font = glNewFontFromParent((glCompObj *) p, NULL);
-    p->text = (char *) 0;
+    p->text = NULL;
     p->common.functions.draw = (glcompdrawfunc_t)glCompPanelDraw;
-    p->image = (glCompImage *) 0;
+    p->image = NULL;
     return p;
 }
 void glCompSetPanelText(glCompPanel * p, char *t)
@@ -62,8 +62,8 @@ int glCompPanelDraw(glCompObj * o)
     if (!p->common.visible)
 	return 0;
     /*draw shadow */
-    glColor4f((GLfloat) p->shadowcolor.R, (GLfloat) p->shadowcolor.G,
-	      (GLfloat) p->shadowcolor.B, (GLfloat) p->shadowcolor.A);
+    glColor4f(p->shadowcolor.R, p->shadowcolor.G, p->shadowcolor.B,
+              p->shadowcolor.A);
     r.h = p->shadowwidth;
     r.w = ref.width;
     r.pos.x = ref.pos.x + p->shadowwidth;
@@ -77,11 +77,11 @@ int glCompPanelDraw(glCompObj * o)
     r.pos.z = -0.001f;
     glCompDrawRectangle(&r);
     /*draw panel */
-    glCompDrawRectPrism(&(ref.pos), ref.width, ref.height,
-			p->common.borderWidth, 0.01f, &(ref.color), 1);
+    glCompDrawRectPrism(&ref.pos, ref.width, ref.height,
+			p->common.borderWidth, 0.01f, &ref.color, 1);
     /*draw image if there is */
     if (p->image) {
-	p->image->common.callbacks.draw((void *) p->image);
+	p->image->common.callbacks.draw(p->image);
     }
     return 1;
 }
