@@ -8,92 +8,15 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include <cgraph/agxbuf.h>
+#include <cgraph/alloc.h>
+#include <cgraph/prisize_t.h>
+#include <cgraph/unreachable.h>
 #include <xdot/xdot.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 
-#define NEW(t)           calloc(1, sizeof(t))
-#define N_NEW(n,t)       calloc((n), sizeof(t))
-
-typedef struct {
-    unsigned char *buf;		/* start of buffer */
-    unsigned char *ptr;		/* next place to write */
-    unsigned char *eptr;	/* end of buffer */
-    int dyna;			/* true if buffer is malloc'ed */
-} agxbuf;
-
-#define agxbuse(X) (agxbputc(X,'\0'),(char*)((X)->ptr = (X)->buf))
-
-static void agxbinit(agxbuf * xb, unsigned int hint, unsigned char *init)
-{
-    if (init) {
-	xb->buf = init;
-	xb->dyna = 0;
-    } else {
-	if (hint == 0)
-	    hint = BUFSIZ;
-	xb->dyna = 1;
-	xb->buf = N_NEW(hint, unsigned char);
-    }
-    xb->eptr = xb->buf + hint;
-    xb->ptr = xb->buf;
-    *xb->ptr = '\0';
-}
-static int agxbmore(agxbuf * xb, unsigned int ssz)
-{
-    int cnt;			/* current no. of characters in buffer */
-    int size;			/* current buffer size */
-    int nsize;			/* new buffer size */
-    unsigned char *nbuf;	/* new buffer */
-
-    size = xb->eptr - xb->buf;
-    nsize = 2 * size;
-    if (size + ssz > nsize)
-	nsize = size + ssz;
-    cnt = xb->ptr - xb->buf;
-    if (xb->dyna) {
-	nbuf = realloc(xb->buf, nsize);
-    } else {
-	nbuf = N_NEW(nsize, unsigned char);
-	memcpy(nbuf, xb->buf, cnt);
-	xb->dyna = 1;
-    }
-    xb->buf = nbuf;
-    xb->ptr = xb->buf + cnt;
-    xb->eptr = xb->buf + nsize;
-    return 0;
-}
-
-static int agxbput(char *s, agxbuf * xb)
-{
-    unsigned int ssz = strlen(s);
-    if (xb->ptr + ssz > xb->eptr)
-	agxbmore(xb, ssz);
-    memcpy(xb->ptr, s, ssz);
-    xb->ptr += ssz;
-    return ssz;
-}
-
-static int agxbputc(agxbuf * xb, char c) {
-  if (xb->ptr >= xb->eptr) {
-    if (agxbmore(xb, 1) != 0) {
-      return -1;
-    }
-  }
-  *xb->ptr++ = (unsigned char)c;
-  return 0;
-}
-
-/* agxbfree:
- * Free any malloced resources.
- */
-static void agxbfree(agxbuf * xb)
-{
-    if (xb->dyna)
-	free(xb->buf);
-}
-
 /* the parse functions should return NULL on error */
 static char *parseReal(char *s, double *fp)
 {
@@ -163,27 +86,27 @@ static char *parseRect(char *s, xdot_rect * rp)
 
 static char *parsePolyline(char *s, xdot_polyline * pp)
 {
-    int i;
+    unsigned i;
     xdot_point *pts;
     xdot_point *ps;
     char* endp;
 
-    s = parseInt(s, &i);
-    if (!s) return s;
-    pts = ps = N_NEW(i, xdot_point);
+    s = parseUInt(s, &i);
+    if (!s) return NULL;
+    pts = ps = gv_calloc(i, sizeof(ps[0]));
     pp->cnt = i;
     for (i = 0; i < pp->cnt; i++) {
 	ps->x = strtod (s, &endp);
 	if (s == endp) {
 	    free (pts);
-	    return 0;
+	    return NULL;
 	}
 	else
 	    s = endp;
 	ps->y = strtod (s, &endp);
 	if (s == endp) {
 	    free (pts);
-	    return 0;
+	    return NULL;
 	}
 	else
 	    s = endp;
@@ -197,8 +120,6 @@ static char *parsePolyline(char *s, xdot_polyline * pp)
 static char *parseString(char *s, char **sp)
 {
     int i;
-    char *c;
-    char *p;
     s = parseInt(s, &i);
     if (!s || i <= 0) return 0;
     while (*s && *s != '-') s++;
@@ -206,20 +127,15 @@ static char *parseString(char *s, char **sp)
     else {
 	return 0;
     }
-    c = N_NEW(i + 1, char);
-    p = c;
-    while (i > 0 && *s) {
-	*p++ = *s++;
-	i--;
-    }
-    if (i > 0) {
+
+    char *c = gv_strndup(s, (size_t)i);
+    if (strlen(c) != (size_t)i) {
 	free (c);
 	return 0;
     }
 
-    *p = '\0';
     *sp = c;
-    return s;
+    return s + i;
 }
 
 static char *parseAlign(char *s, xdot_align * ap)
@@ -244,7 +160,7 @@ static char *parseOp(xdot_op * op, char *s, drawfunc_t ops[], int* error)
     xdot_color clr;
 
     *error = 0;
-    while (isspace(*s))
+    while (isspace((int)*s))
 	s++;
     switch (*s++) {
     case 'E':
@@ -412,45 +328,41 @@ static char *parseOp(xdot_op * op, char *s, drawfunc_t ops[], int* error)
  * Parse and append additional xops onto a given xdot object.
  * Return x.
  */ 
-xdot *parseXDotFOn (char *s, drawfunc_t fns[], int sz, xdot* x)
-{
+xdot *parseXDotFOn(char *s, drawfunc_t fns[], size_t sz, xdot *x) {
     xdot_op op;
     char *ops;
-    int oldsz, bufsz;
+    size_t oldsz, bufsz;
     int error;
-    int initcnt;
 
     if (!s)
 	return x;
 
     if (!x) {
-	x = NEW(xdot);
+	x = gv_alloc(sizeof(*x));
 	if (sz <= sizeof(xdot_op))
 	    sz = sizeof(xdot_op);
 
-	/* cnt, freefunc, ops, flags zeroed by NEW */
+	/* cnt, freefunc, ops, flags zeroed by gv_alloc */
 	x->sz = sz;
     }
-    initcnt = x->cnt;
+    size_t initcnt = x->cnt;
     sz = x->sz;
 
     if (initcnt == 0) {
 	bufsz = XDBSIZE;
-	ops = calloc(XDBSIZE, sz);
+	ops = gv_calloc(XDBSIZE, sz);
     }
     else {
 	ops = (char*)(x->ops);
 	bufsz = initcnt + XDBSIZE;
-	ops = realloc(ops, bufsz * sz);
-	memset(ops + initcnt*sz, '\0', (bufsz - initcnt)*sz);
+	ops = gv_recalloc(ops, initcnt, bufsz, sz);
     }
 
     while ((s = parseOp(&op, s, fns, &error))) {
 	if (x->cnt == bufsz) {
 	    oldsz = bufsz;
 	    bufsz *= 2;
-	    ops = realloc(ops, bufsz * sz);
-	    memset(ops + oldsz*sz, '\0', (bufsz - oldsz)*sz);
+	    ops = gv_recalloc(ops, oldsz, bufsz, sz);
 	}
 	*(xdot_op *) (ops + x->cnt * sz) = op;
 	x->cnt++;
@@ -458,7 +370,7 @@ xdot *parseXDotFOn (char *s, drawfunc_t fns[], int sz, xdot* x)
     if (error)
 	x->flags |= XDOT_PARSE_ERROR;
     if (x->cnt) {
-	x->ops = realloc(ops, x->cnt * sz);
+	x->ops = gv_recalloc(ops, bufsz, x->cnt, sz);
     }
     else {
 	free (ops);
@@ -470,8 +382,7 @@ xdot *parseXDotFOn (char *s, drawfunc_t fns[], int sz, xdot* x)
 
 }
 
-xdot *parseXDotF(char *s, drawfunc_t fns[], int sz)
-{
+xdot *parseXDotF(char *s, drawfunc_t fns[], size_t sz) {
     return parseXDotFOn (s, fns, sz, NULL);
 }
 
@@ -480,7 +391,7 @@ xdot *parseXDot(char *s)
     return parseXDotF(s, 0, 0);
 }
 
-typedef void (*pf) (char *, void *);
+typedef int (*pf)(void*, char*, ...);
 
 /* trim:
  * Trailing zeros are removed and decimal point, if possible.
@@ -508,54 +419,39 @@ static void printRect(xdot_rect * r, pf print, void *info)
 
     snprintf(buf, sizeof(buf), " %.02f", r->x);
     trim(buf);
-    print(buf, info);
+    print(info, "%s", buf);
     snprintf(buf, sizeof(buf), " %.02f", r->y);
     trim(buf);
-    print(buf, info);
+    print(info, "%s", buf);
     snprintf(buf, sizeof(buf), " %.02f", r->w);
     trim(buf);
-    print(buf, info);
+    print(info, "%s", buf);
     snprintf(buf, sizeof(buf), " %.02f", r->h);
     trim(buf);
-    print(buf, info);
+    print(info, "%s", buf);
 }
 
 static void printPolyline(xdot_polyline * p, pf print, void *info)
 {
-    int i;
     char buf[512];
 
-    snprintf(buf, sizeof(buf), " %d", p->cnt);
-    print(buf, info);
-    for (i = 0; i < p->cnt; i++) {
+    print(info, " %" PRISIZE_T, p->cnt);
+    for (size_t i = 0; i < p->cnt; i++) {
 	snprintf(buf, sizeof(buf), " %.02f", p->pts[i].x);
 	trim(buf);
-	print(buf, info);
+	print(info, "%s", buf);
 	snprintf(buf, sizeof(buf), " %.02f", p->pts[i].y);
 	trim(buf);
-	print(buf, info);
+	print(info, "%s", buf);
     }
 }
 
 static void printString(char *p, pf print, void *info)
 {
-    char buf[30];
-
-    snprintf(buf, sizeof(buf), " %zu -", strlen(p));
-    print(buf, info);
-    print(p, info);
+    print(info, " %" PRISIZE_T " -%s", strlen(p), p);
 }
 
-static void printInt(int i, pf print, void *info)
-{
-    char buf[30];
-
-    snprintf(buf, sizeof(buf), " %d", i);
-    print(buf, info);
-}
-
-static void printFloat(float f, pf print, void *info, int space)
-{
+static void printFloat(double f, pf print, void *info, int space) {
     char buf[128];
 
     if (space)
@@ -563,30 +459,26 @@ static void printFloat(float f, pf print, void *info, int space)
     else
 	snprintf(buf, sizeof(buf), "%.02f", f);
     trim (buf);
-    print(buf, info);
+    print(info, "%s", buf);
 }
 
 static void printAlign(xdot_align a, pf print, void *info)
 {
     switch (a) {
     case xd_left:
-	print(" -1", info);
+	print(info, " -1");
 	break;
     case xd_right:
-	print(" 1", info);
+	print(info, " 1");
 	break;
     case xd_center:
-	print(" 0", info);
+	print(info, " 0");
 	break;
+    default:
+	UNREACHABLE();
     }
 }
 
-static void
-gradprint (char* s, void* v)
-{
-    agxbput(s, (agxbuf*)v);
-}
-
 static void
 toGradString (agxbuf* xb, xdot_color* cp)
 {
@@ -595,28 +487,28 @@ toGradString (agxbuf* xb, xdot_color* cp)
 
     if (cp->type == xd_linear) {
 	agxbputc (xb, '[');
-	printFloat (cp->u.ling.x0, gradprint, xb, 0);
-	printFloat (cp->u.ling.y0, gradprint, xb, 1);
-	printFloat (cp->u.ling.x1, gradprint, xb, 1);
-	printFloat (cp->u.ling.y1, gradprint, xb, 1);
+	printFloat (cp->u.ling.x0, (pf)agxbprint, xb, 0);
+	printFloat (cp->u.ling.y0, (pf)agxbprint, xb, 1);
+	printFloat (cp->u.ling.x1, (pf)agxbprint, xb, 1);
+	printFloat (cp->u.ling.y1, (pf)agxbprint, xb, 1);
 	n_stops = cp->u.ling.n_stops;
 	stops = cp->u.ling.stops;
     }
     else {
 	agxbputc (xb, '(');
-	printFloat (cp->u.ring.x0, gradprint, xb, 0);
-	printFloat (cp->u.ring.y0, gradprint, xb, 1);
-	printFloat (cp->u.ring.r0, gradprint, xb, 1);
-	printFloat (cp->u.ring.x1, gradprint, xb, 1);
-	printFloat (cp->u.ring.y1, gradprint, xb, 1);
-	printFloat (cp->u.ring.r1, gradprint, xb, 1);
+	printFloat (cp->u.ring.x0, (pf)agxbprint, xb, 0);
+	printFloat (cp->u.ring.y0, (pf)agxbprint, xb, 1);
+	printFloat (cp->u.ring.r0, (pf)agxbprint, xb, 1);
+	printFloat (cp->u.ring.x1, (pf)agxbprint, xb, 1);
+	printFloat (cp->u.ring.y1, (pf)agxbprint, xb, 1);
+	printFloat (cp->u.ring.r1, (pf)agxbprint, xb, 1);
 	n_stops = cp->u.ring.n_stops;
 	stops = cp->u.ring.stops;
     }
-    printInt (n_stops, gradprint, xb);
+    agxbprint(xb, " %d", n_stops);
     for (i = 0; i < n_stops; i++) {
-	printFloat (stops[i].frac, gradprint, xb, 1);
-	printString (stops[i].color, gradprint, xb);
+	printFloat (stops[i].frac, (pf)agxbprint, xb, 1);
+	printString (stops[i].color, (pf)agxbprint, xb);
     }
 
     if (cp->type == xd_linear)
@@ -630,230 +522,208 @@ typedef void (*print_op)(xdot_op * op, pf print, void *info, int more);
 static void printXDot_Op(xdot_op * op, pf print, void *info, int more)
 {
     agxbuf xb;
-    unsigned char buf[BUFSIZ];
+    char buf[BUFSIZ];
 
     agxbinit (&xb, BUFSIZ, buf);
     switch (op->kind) {
     case xd_filled_ellipse:
-	print("E", info);
+	print(info, "E");
 	printRect(&op->u.ellipse, print, info);
 	break;
     case xd_unfilled_ellipse:
-	print("e", info);
+	print(info, "e");
 	printRect(&op->u.ellipse, print, info);
 	break;
     case xd_filled_polygon:
-	print("P", info);
+	print(info, "P");
 	printPolyline(&op->u.polygon, print, info);
 	break;
     case xd_unfilled_polygon:
-	print("p", info);
+	print(info, "p");
 	printPolyline(&op->u.polygon, print, info);
 	break;
     case xd_filled_bezier:
-	print("b", info);
+	print(info, "b");
 	printPolyline(&op->u.bezier, print, info);
 	break;
     case xd_unfilled_bezier:
-	print("B", info);
+	print(info, "B");
 	printPolyline(&op->u.bezier, print, info);
 	break;
     case xd_pen_color:
-	print("c", info);
+	print(info, "c");
 	printString(op->u.color, print, info);
 	break;
     case xd_grad_pen_color:
-	print("c", info);
+	print(info, "c");
 	toGradString (&xb, &op->u.grad_color);
 	printString(agxbuse(&xb), print, info);
 	break;
     case xd_fill_color:
-	print("C", info);
+	print(info, "C");
 	printString(op->u.color, print, info);
 	break;
     case xd_grad_fill_color:
-	print("C", info);
+	print(info, "C");
 	toGradString (&xb, &op->u.grad_color);
 	printString(agxbuse(&xb), print, info);
 	break;
     case xd_polyline:
-	print("L", info);
+	print(info, "L");
 	printPolyline(&op->u.polyline, print, info);
 	break;
     case xd_text:
-	print("T", info);
-	printInt(op->u.text.x, print, info);
-	printInt(op->u.text.y, print, info);
+	print(info, "T %.f %.f", op->u.text.x, op->u.text.y);
 	printAlign(op->u.text.align, print, info);
-	printInt(op->u.text.width, print, info);
+	print(info, " %.f", op->u.text.width);
 	printString(op->u.text.text, print, info);
 	break;
     case xd_font:
-	print("F", info);
+	print(info, "F");
 	printFloat(op->u.font.size, print, info, 1);
 	printString(op->u.font.name, print, info);
 	break;
     case xd_fontchar:
-	print("t", info);
-	printInt(op->u.fontchar, print, info);
+	print(info, "t %u", op->u.fontchar);
 	break;
     case xd_style:
-	print("S", info);
+	print(info, "S");
 	printString(op->u.style, print, info);
 	break;
     case xd_image:
-	print("I", info);
+	print(info, "I");
 	printRect(&op->u.image.pos, print, info);
 	printString(op->u.image.name, print, info);
 	break;
     }
     if (more)
-	print(" ", info);
+	print(info, " ");
     agxbfree (&xb);
 }
 
 static void jsonRect(xdot_rect * r, pf print, void *info)
 {
-    char buf[128];
-
-    snprintf(buf, sizeof(buf), "[%.06f,%.06f,%.06f,%.06f]", r->x, r->y, r->w,
-             r->h);
-    print(buf, info);
+  print(info, "[%.06f,%.06f,%.06f,%.06f]", r->x, r->y, r->w, r->h);
 }
 
 static void jsonPolyline(xdot_polyline * p, pf print, void *info)
 {
-    int i;
-    char buf[128];
-
-    print("[", info);
-    for (i = 0; i < p->cnt; i++) {
-	snprintf(buf, sizeof(buf), "%.06f,%.06f", p->pts[i].x, p->pts[i].y);
-	print(buf, info);
-	if (i < p->cnt-1) print(",", info);
+    print(info, "[");
+    for (size_t i = 0; i < p->cnt; i++) {
+	print(info, "%.06f,%.06f", p->pts[i].x, p->pts[i].y);
+	if (i < p->cnt-1) print(info, ",");
     }
-    print("]", info);
+    print(info, "]");
 }
 
 static void jsonString(char *p, pf print, void *info)
 {
     char c;
 
-    print("\"", info);
+    print(info, "\"");
     while ((c = *p++)) {
-	if (c == '"') print("\\\"", info);
-	else if (c == '\\') print("\\\\", info);
-	else {
-		char buf[2] = { c, '\0' };
-		print(buf, info);
-	}
+	if (c == '"') print(info, "\\\"");
+	else if (c == '\\') print(info, "\\\\");
+	else print(info, "%c", c);
     }
-    print("\"", info);
+    print(info, "\"");
 }
 
 static void jsonXDot_Op(xdot_op * op, pf print, void *info, int more)
 {
     agxbuf xb;
-    unsigned char buf[BUFSIZ];
+    char buf[BUFSIZ];
 
     agxbinit (&xb, BUFSIZ, buf);
     switch (op->kind) {
     case xd_filled_ellipse:
-	print("{E : ", info);
+	print(info, "{\"E\" : ");
 	jsonRect(&op->u.ellipse, print, info);
 	break;
     case xd_unfilled_ellipse:
-	print("{e : ", info);
+	print(info, "{\"e\" : ");
 	jsonRect(&op->u.ellipse, print, info);
 	break;
     case xd_filled_polygon:
-	print("{P : ", info);
+	print(info, "{\"P\" : ");
 	jsonPolyline(&op->u.polygon, print, info);
 	break;
     case xd_unfilled_polygon:
-	print("{p : ", info);
+	print(info, "{\"p\" : ");
 	jsonPolyline(&op->u.polygon, print, info);
 	break;
     case xd_filled_bezier:
-	print("{b : ", info);
+	print(info, "{\"b\" : ");
 	jsonPolyline(&op->u.bezier, print, info);
 	break;
     case xd_unfilled_bezier:
-	print("{B : ", info);
+	print(info, "{\"B\" : ");
 	jsonPolyline(&op->u.bezier, print, info);
 	break;
     case xd_pen_color:
-	print("{c : ", info);
+	print(info, "{\"c\" : ");
 	jsonString(op->u.color, print, info);
 	break;
     case xd_grad_pen_color:
-	print("{c : ", info);
+	print(info, "{\"c\" : ");
 	toGradString (&xb, &op->u.grad_color);
 	jsonString(agxbuse(&xb), print, info);
 	break;
     case xd_fill_color:
-	print("{C : ", info);
+	print(info, "{\"C\" : ");
 	jsonString(op->u.color, print, info);
 	break;
     case xd_grad_fill_color:
-	print("{C : ", info);
+	print(info, "{\"C\" : ");
 	toGradString (&xb, &op->u.grad_color);
 	jsonString(agxbuse(&xb), print, info);
 	break;
     case xd_polyline:
-	print("{L :", info);
+	print(info, "{\"L\" :");
 	jsonPolyline(&op->u.polyline, print, info);
 	break;
     case xd_text:
-	print("{T : [", info);
-	printInt(op->u.text.x, print, info);
-	print(",", info);
-	printInt(op->u.text.y, print, info);
-	print(",", info);
+	print(info, "{\"T\" : [ %.f, %.f,", op->u.text.x, op->u.text.y);
 	printAlign(op->u.text.align, print, info);
-	print(",", info);
-	printInt(op->u.text.width, print, info);
-	print(",", info);
+	print(info, ", %.f,", op->u.text.width);
 	jsonString(op->u.text.text, print, info);
-	print("]", info);
+	print(info, "]");
 	break;
     case xd_font:
-	print("{F : [", info);
+	print(info, "{\"F\" : [");
 	op->kind = xd_font;
 	printFloat(op->u.font.size, print, info, 1);
-	print(",", info);
+	print(info, ",");
 	jsonString(op->u.font.name, print, info);
-	print("]", info);
+	print(info, "]");
 	break;
     case xd_fontchar:
-	print("{t : ", info);
-	printInt(op->u.fontchar, print, info);
+	print(info, "{\"t\" :  %u", op->u.fontchar);
 	break;
     case xd_style:
-	print("{S : ", info);
+	print(info, "{\"S\" : ");
 	jsonString(op->u.style, print, info);
 	break;
     case xd_image:
-	print("{I : [", info);
+	print(info, "{\"I\" : [");
 	jsonRect(&op->u.image.pos, print, info);
-	print(",", info);
+	print(info, ",");
 	jsonString(op->u.image.name, print, info);
-	print("]", info);
+	print(info, "]");
 	break;
     }
     if (more)
-	print("},\n", info);
+	print(info, "},\n");
     else
-	print("}\n", info);
+	print(info, "}\n");
     agxbfree (&xb);
 }
 
 static void _printXDot(xdot * x, pf print, void *info, print_op ofn)
 {
-    int i;
     xdot_op *op;
     char *base = (char *) (x->ops);
-    for (i = 0; i < x->cnt; i++) {
+    for (size_t i = 0; i < x->cnt; i++) {
 	op = (xdot_op *) (base + i * x->sz);
 	ofn(op, print, info, i < x->cnt - 1);
     }
@@ -861,26 +731,22 @@ static void _printXDot(xdot * x, pf print, void *info, print_op ofn)
 
 char *sprintXDot(xdot * x)
 {
-    char *s;
-    unsigned char buf[BUFSIZ];
+    char buf[BUFSIZ];
     agxbuf xb;
     agxbinit(&xb, BUFSIZ, buf);
-    _printXDot(x, (pf) agxbput, &xb, printXDot_Op);
-    s = strdup(agxbuse(&xb));
-    agxbfree(&xb);
-
-    return s;
+    _printXDot(x, (pf)agxbprint, &xb, printXDot_Op);
+    return agxbdisown(&xb);
 }
 
 void fprintXDot(FILE * fp, xdot * x)
 {
-    _printXDot(x, (pf) fputs, fp, printXDot_Op);
+    _printXDot(x, (pf)fprintf, fp, printXDot_Op);
 }
 
 void jsonXDot(FILE * fp, xdot * x)
 {
     fputs ("[\n", fp);
-    _printXDot(x, (pf) fputs, fp, jsonXDot_Op);
+    _printXDot(x, (pf)fprintf, fp, jsonXDot_Op);
     fputs ("]\n", fp);
 }
 
@@ -925,14 +791,13 @@ static void freeXOpData(xdot_op * x)
 
 void freeXDot (xdot * x)
 {
-    int i;
     xdot_op *op;
     char *base;
     freefunc_t ff = x->freefunc;
 
     if (!x) return;
     base = (char *) (x->ops);
-    for (i = 0; i < x->cnt; i++) {
+    for (size_t i = 0; i < x->cnt; i++) {
 	op = (xdot_op *) (base + i * x->sz);
 	if (ff) ff (op);
 	freeXOpData(op);
@@ -943,7 +808,6 @@ void freeXDot (xdot * x)
 
 int statXDot (xdot* x, xdot_stats* sp)
 {
-    int i;
     xdot_op *op;
     char *base;
 
@@ -951,7 +815,7 @@ int statXDot (xdot* x, xdot_stats* sp)
     memset(sp, 0, sizeof(xdot_stats));
     sp->cnt = x->cnt;
     base = (char *) (x->ops);
-    for (i = 0; i < x->cnt; i++) {
+    for (size_t i = 0; i < x->cnt; i++) {
 	op = (xdot_op *) (base + i * x->sz);
  	switch (op->kind) {
 	case xd_filled_ellipse:
@@ -1033,7 +897,7 @@ radGradient (char* cp, xdot_color* clr)
     s = parseInt(s, &clr->u.ring.n_stops);
     CHK1(s);
 
-    stops = N_NEW(clr->u.ring.n_stops,xdot_color_stop);
+    stops = gv_calloc(clr->u.ring.n_stops, sizeof(stops[0]));
     for (i = 0; i < clr->u.ring.n_stops; i++) {
 	s = parseReal(s, &d);
 	CHK1(s);
@@ -1070,7 +934,7 @@ linGradient (char* cp, xdot_color* clr)
     s = parseInt(s, &clr->u.ling.n_stops);
     CHK1(s);
 
-    stops = N_NEW(clr->u.ling.n_stops,xdot_color_stop);
+    stops = gv_calloc(clr->u.ling.n_stops, sizeof(stops[0]));
     for (i = 0; i < clr->u.ling.n_stops; i++) {
 	s = parseReal(s, &d);
 	CHK1(s);
