@@ -10,6 +10,7 @@
 
 #include "config.h"
 
+#include <stdbool.h>
 #include <stdlib.h>
 
 #include <gvc/gvplugin_loadimage.h>
@@ -37,18 +38,6 @@ typedef enum {
     FORMAT_TIFF_CAIRO,
 } format_type;
 
-#if 0
-// FIXME - should be using a stream reader
-static cairo_status_t
-reader (void *closure, unsigned char *data, unsigned int length)
-{
-    if (length == fread(data, 1, length, (FILE *)closure)
-     || feof((FILE *)closure))
-        return CAIRO_STATUS_SUCCESS;
-    return CAIRO_STATUS_READ_ERROR;
-}
-#endif
-
 #ifdef HAVE_CAIRO_SURFACE_SET_MIME_DATA
 static void gdk_set_mimedata_from_file (cairo_surface_t *image, const char *mime_type, const char *file)
 {
@@ -102,9 +91,9 @@ static void gdk_set_mimedata(cairo_surface_t *image, usershape_t *us)
 static void gdk_freeimage(usershape_t *us)
 {
 #ifndef HAVE_CAIRO_SURFACE_SET_MIME_DATA
-    g_object_unref((GdkPixbuf*)(us->data));
+    g_object_unref(us->data);
 #else /* HAVE_CAIRO_SURFACE_SET_MIME_DATA */
-    cairo_surface_destroy ((cairo_surface_t *)(us->data));
+    cairo_surface_destroy(us->data);
 #endif /* HAVE_CAIRO_SURFACE_SET_MIME_DATA */
 }
 
@@ -115,7 +104,7 @@ static cairo_surface_t* gdk_loadimage(GVJ_t * job, usershape_t *us)
 #endif /* HAVE_CAIRO_SURFACE_SET_MIME_DATA */
 {
 #ifdef HAVE_CAIRO_SURFACE_SET_MIME_DATA
-    cairo_t *cr = (cairo_t *) job->context; /* target context */
+    cairo_t *cr = job->context; /* target context */
 #endif /* HAVE_CAIRO_SURFACE_SET_MIME_DATA */
     GdkPixbuf *image = NULL;
 #ifdef HAVE_CAIRO_SURFACE_SET_MIME_DATA
@@ -130,7 +119,7 @@ static cairo_surface_t* gdk_loadimage(GVJ_t * job, usershape_t *us)
     if (us->data) {
 #ifndef HAVE_CAIRO_SURFACE_SET_MIME_DATA
         if (us->datafree == gdk_freeimage)
-             image = (GdkPixbuf*)(us->data); /* use cached data */
+             image = us->data; /* use cached data */
         else {
              us->datafree(us);        /* free incompatible cache data */
              us->datafree = NULL;
@@ -171,7 +160,7 @@ static cairo_surface_t* gdk_loadimage(GVJ_t * job, usershape_t *us)
 #endif /* HAVE_CAIRO_SURFACE_SET_MIME_DATA */
         if (image) {
 #ifndef HAVE_CAIRO_SURFACE_SET_MIME_DATA
-            us->data = (void*)image;
+            us->data = image;
 #else /* HAVE_CAIRO_SURFACE_SET_MIME_DATA */
             cairo_save (cr);
             gdk_cairo_set_source_pixbuf (cr, image, 0, 0);
@@ -181,7 +170,7 @@ static cairo_surface_t* gdk_loadimage(GVJ_t * job, usershape_t *us)
             cairo_image = cairo_surface_reference (cairo_image);
             cairo_restore (cr);
             gdk_set_mimedata (cairo_image, us);
-            us->data = (void*)cairo_surface_reference (cairo_image);
+            us->data = cairo_surface_reference(cairo_image);
 #endif /* HAVE_CAIRO_SURFACE_SET_MIME_DATA */
             us->datafree = gdk_freeimage;
         }
@@ -198,9 +187,11 @@ static cairo_surface_t* gdk_loadimage(GVJ_t * job, usershape_t *us)
 #endif /* HAVE_CAIRO_SURFACE_SET_MIME_DATA */
 }
 
-static void gdk_loadimage_cairo(GVJ_t * job, usershape_t *us, boxf b, boolean filled)
+static void gdk_loadimage_cairo(GVJ_t * job, usershape_t *us, boxf b, bool filled)
 {
-    cairo_t *cr = (cairo_t *) job->context; /* target context */
+    (void)filled;
+
+    cairo_t *cr = job->context; /* target context */
 #ifndef HAVE_CAIRO_SURFACE_SET_MIME_DATA
     GdkPixbuf *image;
 #else /* HAVE_CAIRO_SURFACE_SET_MIME_DATA */
